gegl r2169 - in trunk: . gegl/buffer
- From: ok svn gnome org
- To: svn-commits-list gnome org
- Subject: gegl r2169 - in trunk: . gegl/buffer
- Date: Mon, 14 Apr 2008 23:27:05 +0100 (BST)
Author: ok
Date: Mon Apr 14 23:27:05 2008
New Revision: 2169
URL: http://svn.gnome.org/viewvc/gegl?rev=2169&view=rev
Log:
s/Provider/Source/g s/provider/source/g s/PROVIDER/SOURCE/g
* gegl/buffer/Makefile.am:
* gegl/buffer/gegl-buffer-allocator.c:
* gegl/buffer/gegl-buffer-load.c:
* gegl/buffer/gegl-buffer-private.h:
* gegl/buffer/gegl-buffer-save.c:
* gegl/buffer/gegl-buffer-types.h:
* gegl/buffer/gegl-buffer.c:
* gegl/buffer/gegl-handler-cache.c:
* gegl/buffer/gegl-handler-empty.c:
* gegl/buffer/gegl-handler-log.c:
* gegl/buffer/gegl-handler-zoom.c:
* gegl/buffer/gegl-handler.c:
* gegl/buffer/gegl-handler.h:
* gegl/buffer/gegl-handlers.c:
* gegl/buffer/gegl-handlers.h:
* gegl/buffer/gegl-provider.c:
* gegl/buffer/gegl-provider.h:
* gegl/buffer/gegl-source.c:
* gegl/buffer/gegl-source.h:
* gegl/buffer/gegl-storage.c:
* gegl/buffer/gegl-tile-backend.c:
* gegl/buffer/gegl-tile-backend.h:
* gegl/buffer/gegl-tile-disk.c:
* gegl/buffer/gegl-tile-gio.c:
* gegl/buffer/gegl-tile-mem.c:
* gegl/buffer/gegl-tile.c:
Added:
trunk/gegl/buffer/gegl-source.c
- copied, changed from r2168, /trunk/gegl/buffer/gegl-provider.c
trunk/gegl/buffer/gegl-source.h
- copied, changed from r2168, /trunk/gegl/buffer/gegl-provider.h
Removed:
trunk/gegl/buffer/gegl-provider.c
trunk/gegl/buffer/gegl-provider.h
Modified:
trunk/ChangeLog
trunk/gegl/buffer/Makefile.am
trunk/gegl/buffer/gegl-buffer-allocator.c
trunk/gegl/buffer/gegl-buffer-load.c
trunk/gegl/buffer/gegl-buffer-private.h
trunk/gegl/buffer/gegl-buffer-save.c
trunk/gegl/buffer/gegl-buffer-types.h
trunk/gegl/buffer/gegl-buffer.c
trunk/gegl/buffer/gegl-handler-cache.c
trunk/gegl/buffer/gegl-handler-empty.c
trunk/gegl/buffer/gegl-handler-log.c
trunk/gegl/buffer/gegl-handler-zoom.c
trunk/gegl/buffer/gegl-handler.c
trunk/gegl/buffer/gegl-handler.h
trunk/gegl/buffer/gegl-handlers.c
trunk/gegl/buffer/gegl-handlers.h
trunk/gegl/buffer/gegl-storage.c
trunk/gegl/buffer/gegl-tile-backend.c
trunk/gegl/buffer/gegl-tile-backend.h
trunk/gegl/buffer/gegl-tile-disk.c
trunk/gegl/buffer/gegl-tile-gio.c
trunk/gegl/buffer/gegl-tile-mem.c
trunk/gegl/buffer/gegl-tile.c
Modified: trunk/gegl/buffer/Makefile.am
==============================================================================
--- trunk/gegl/buffer/Makefile.am (original)
+++ trunk/gegl/buffer/Makefile.am Mon Apr 14 23:27:05 2008
@@ -25,7 +25,7 @@
gegl-handler-log.c \
gegl-handler-zoom.c \
gegl-id-pool.c \
- gegl-provider.c
+ gegl-source.c
BUFFER_headers = \
gegl-buffer-allocator.h \
@@ -54,7 +54,7 @@
gegl-handler-log.h \
gegl-handler-zoom.h \
gegl-id-pool.h \
- gegl-provider.h
+ gegl-source.h
libbuffer_la_SOURCES = $(BUFFER_sources) $(BUFFER_headers)
Modified: trunk/gegl/buffer/gegl-buffer-allocator.c
==============================================================================
--- trunk/gegl/buffer/gegl-buffer-allocator.c (original)
+++ trunk/gegl/buffer/gegl-buffer-allocator.c Mon Apr 14 23:27:05 2008
@@ -117,7 +117,7 @@
allocator->max_height = needed_height;
{ GeglBuffer *tmp = g_object_new (GEGL_TYPE_BUFFER,
- "provider", allocator,
+ "source", allocator,
"x", x,
"y", y,
"width", width,
@@ -210,7 +210,7 @@
"path", path,
NULL);
allocator = g_object_new (GEGL_TYPE_BUFFER_ALLOCATOR,
- "provider", storage,
+ "source", storage,
NULL);
g_object_unref (storage);
@@ -224,7 +224,7 @@
"format", babl_format,
NULL);
allocator = g_object_new (GEGL_TYPE_BUFFER_ALLOCATOR,
- "provider", storage,
+ "source", storage,
NULL);
g_object_unref (storage);
g_hash_table_insert (allocators, (gpointer)babl_format, allocator);
Modified: trunk/gegl/buffer/gegl-buffer-load.c
==============================================================================
--- trunk/gegl/buffer/gegl-buffer-load.c (original)
+++ trunk/gegl/buffer/gegl-buffer-load.c Mon Apr 14 23:27:05 2008
@@ -152,10 +152,10 @@
gint factor = 1 << entry->z;
- tile = gegl_provider_get_tile (GEGL_PROVIDER (buffer),
- entry->x + info->x_tile_shift / factor,
- entry->y + info->y_tile_shift / factor,
- entry->z);
+ tile = gegl_source_get_tile (GEGL_SOURCE (buffer),
+ entry->x + info->x_tile_shift / factor,
+ entry->y + info->y_tile_shift / factor,
+ entry->z);
g_assert (tile);
gegl_tile_lock (tile);
Modified: trunk/gegl/buffer/gegl-buffer-private.h
==============================================================================
--- trunk/gegl/buffer/gegl-buffer-save.c (original)
+++ trunk/gegl/buffer/gegl-buffer-save.c Mon Apr 14 23:27:05 2008
@@ -231,7 +231,7 @@
gint tx = gegl_tile_indice (tiledx / factor, tile_width);
gint ty = gegl_tile_indice (tiledy / factor, tile_height);
- if (gegl_provider_exist (GEGL_PROVIDER (buffer), tx, ty, z))
+ if (gegl_source_exist (GEGL_SOURCE (buffer), tx, ty, z))
{
tx += info->x_tile_shift / factor;
ty += info->y_tile_shift / factor;
@@ -293,10 +293,10 @@
GeglTile *tile;
gint factor = 1 << entry->z;
- tile = gegl_provider_get_tile (GEGL_PROVIDER (buffer),
- entry->x - info->x_tile_shift / factor,
- entry->y - info->y_tile_shift / factor,
- entry->z);
+ tile = gegl_source_get_tile (GEGL_SOURCE (buffer),
+ entry->x - info->x_tile_shift / factor,
+ entry->y - info->y_tile_shift / factor,
+ entry->z);
g_assert (tile);
data = gegl_tile_get_data (tile);
g_assert (data);
Modified: trunk/gegl/buffer/gegl-buffer-types.h
==============================================================================
--- trunk/gegl/buffer/gegl-buffer-types.h (original)
+++ trunk/gegl/buffer/gegl-buffer-types.h Mon Apr 14 23:27:05 2008
@@ -24,8 +24,8 @@
typedef struct _GeglTile GeglTile;
typedef struct _GeglTileClass GeglTileClass;
-typedef struct _GeglProvider GeglProvider;
-typedef struct _GeglProviderClass GeglProviderClass;
+typedef struct _GeglSource GeglSource;
+typedef struct _GeglSourceClass GeglSourceClass;
typedef struct _GeglTileBackend GeglTileBackend;
typedef struct _GeglTileBackendClass GeglTileBackendClass;
Modified: trunk/gegl/buffer/gegl-buffer.c
==============================================================================
--- trunk/gegl/buffer/gegl-handler-cache.c (original)
+++ trunk/gegl/buffer/gegl-handler-cache.c Mon Apr 14 23:27:05 2008
@@ -98,13 +98,13 @@
}
static GeglTile *
-get_tile (GeglProvider *tile_store,
+get_tile (GeglSource *tile_store,
gint x,
gint y,
gint z)
{
GeglHandlerCache *cache = GEGL_HANDLER_CACHE (tile_store);
- GeglProvider *provider = GEGL_HANDLER (tile_store)->provider;
+ GeglSource *source = GEGL_HANDLER (tile_store)->source;
GeglTile *tile = NULL;
tile = gegl_handler_cache_get_tile (cache, x, y, z);
@@ -115,8 +115,8 @@
}
cache->misses++;
- if (provider)
- tile = gegl_provider_get_tile (provider, x, y, z);
+ if (source)
+ tile = gegl_source_get_tile (source, x, y, z);
if (tile)
gegl_handler_cache_insert (cache, tile, x, y, z);
@@ -126,7 +126,7 @@
static gpointer
-command (GeglProvider *tile_store,
+command (GeglSource *tile_store,
GeglTileCommand command,
gint x,
gint y,
@@ -223,14 +223,14 @@
gegl_handler_cache_class_init (GeglHandlerCacheClass *class)
{
GObjectClass *gobject_class = G_OBJECT_CLASS (class);
- GeglProviderClass *provider_class = GEGL_PROVIDER_CLASS (class);
+ GeglSourceClass *source_class = GEGL_SOURCE_CLASS (class);
gobject_class->set_property = set_property;
gobject_class->get_property = get_property;
gobject_class->finalize = finalize;
gobject_class->dispose = dispose;
- provider_class->command = command;
+ source_class->command = command;
g_object_class_install_property (gobject_class, PROP_SIZE,
g_param_spec_int ("size",
Modified: trunk/gegl/buffer/gegl-handler-empty.c
==============================================================================
--- trunk/gegl/buffer/gegl-handler-empty.c (original)
+++ trunk/gegl/buffer/gegl-handler-empty.c Mon Apr 14 23:27:05 2008
@@ -42,17 +42,17 @@
}
static GeglTile *
-get_tile (GeglProvider *gegl_provider,
- gint x,
- gint y,
- gint z)
+get_tile (GeglSource *gegl_source,
+ gint x,
+ gint y,
+ gint z)
{
- GeglProvider *provider = GEGL_HANDLER (gegl_provider)->provider;
- GeglHandlerEmpty *empty = GEGL_HANDLER_EMPTY (gegl_provider);
+ GeglSource *source = GEGL_HANDLER (gegl_source)->source;
+ GeglHandlerEmpty *empty = GEGL_HANDLER_EMPTY (gegl_source);
GeglTile *tile = NULL;
- if (provider)
- tile = gegl_provider_get_tile (provider, x, y, z);
+ if (source)
+ tile = gegl_source_get_tile (source, x, y, z);
if (tile != NULL)
return tile;
@@ -131,7 +131,7 @@
static gpointer
-command (GeglProvider *buffer,
+command (GeglSource *buffer,
GeglTileCommand command,
gint x,
gint y,
@@ -148,13 +148,13 @@
gegl_handler_empty_class_init (GeglHandlerEmptyClass *klass)
{
GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
- GeglProviderClass *provider_class = GEGL_PROVIDER_CLASS (klass);
+ GeglSourceClass *source_class = GEGL_SOURCE_CLASS (klass);
gobject_class->constructor = constructor;
gobject_class->finalize = finalize;
gobject_class->set_property = set_property;
gobject_class->get_property = get_property;
- provider_class->command = command;
+ source_class->command = command;
g_object_class_install_property (gobject_class, PROP_BACKEND,
g_param_spec_object ("backend",
Modified: trunk/gegl/buffer/gegl-handler-log.c
==============================================================================
--- trunk/gegl/buffer/gegl-handler-log.c (original)
+++ trunk/gegl/buffer/gegl-handler-log.c Mon Apr 14 23:27:05 2008
@@ -44,14 +44,14 @@
};
static gpointer
-command (GeglProvider *gegl_provider,
+command (GeglSource *gegl_source,
GeglTileCommand command,
gint x,
gint y,
gint z,
gpointer data)
{
- GeglHandler *handler = GEGL_HANDLER (gegl_provider);
+ GeglHandler *handler = GEGL_HANDLER (gegl_source);
gpointer result = NULL;
result = gegl_handler_chain_up (handler, command, x, y, z, data);
@@ -62,7 +62,7 @@
break;
default:
g_print ("(%s %p %p %i,%i,%i => %s)",
- commands[command], (void *) gegl_provider, data, x, y, z,
+ commands[command], (void *) gegl_source, data, x, y, z,
result?"1":"0");
}
return result;
@@ -71,9 +71,9 @@
static void
gegl_handler_log_class_init (GeglHandlerLogClass *klass)
{
- GeglProviderClass *provider_class = GEGL_PROVIDER_CLASS (klass);
+ GeglSourceClass *source_class = GEGL_SOURCE_CLASS (klass);
- provider_class->command = command;
+ source_class->command = command;
}
static void
Modified: trunk/gegl/buffer/gegl-handler-zoom.c
==============================================================================
--- trunk/gegl/buffer/gegl-handler-zoom.c (original)
+++ trunk/gegl/buffer/gegl-handler-zoom.c Mon Apr 14 23:27:05 2008
@@ -190,22 +190,22 @@
}
static GeglTile *
-get_tile (GeglProvider *gegl_provider,
- gint x,
- gint y,
- gint z)
+get_tile (GeglSource *gegl_source,
+ gint x,
+ gint y,
+ gint z)
{
- GeglProvider *provider = GEGL_HANDLER (gegl_provider)->provider;
- GeglHandlerZoom *zoom = GEGL_HANDLER_ZOOM (gegl_provider);
+ GeglSource *source = GEGL_HANDLER (gegl_source)->source;
+ GeglHandlerZoom *zoom = GEGL_HANDLER_ZOOM (gegl_source);
GeglTile *tile = NULL;
Babl *format = (Babl *) (zoom->backend->format);
gint tile_width;
gint tile_height;
gint tile_size;
- if (provider)
+ if (source)
{
- tile = gegl_provider_get_tile (provider, x, y, z);
+ tile = gegl_source_get_tile (source, x, y, z);
}
if (tile != NULL)
@@ -265,7 +265,7 @@
/* we get the tile from ourselves, to make successive rescales work
* correctly */
if (fetch[i][j])
- source_tile[i][j] = gegl_provider_get_tile (gegl_provider,
+ source_tile[i][j] = gegl_source_get_tile (gegl_source,
x * 2 + i, y * 2 + j, z - 1);
}
@@ -328,7 +328,7 @@
}
static gpointer
-command (GeglProvider *tile_store,
+command (GeglSource *tile_store,
GeglTileCommand command,
gint x,
gint y,
@@ -336,7 +336,7 @@
gpointer data)
{
GeglHandler *handler = GEGL_HANDLER (tile_store);
- /*GeglProvider *provider = handler->provider;*/
+ /*GeglSource *source = handler->source;*/
if (command == GEGL_TILE_GET)
return get_tile (tile_store, x, y, z);
@@ -345,7 +345,7 @@
command == GEGL_TILE_VOID_BL ||
command == GEGL_TILE_VOID_BR)
{
- GeglTile *tile = gegl_provider_get_tile (tile_store, x, y, z);
+ GeglTile *tile = gegl_source_get_tile (tile_store, x, y, z);
if (!tile)
return FALSE;
@@ -446,13 +446,13 @@
gegl_handler_zoom_class_init (GeglHandlerZoomClass *klass)
{
GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
- GeglProviderClass *provider_class = GEGL_PROVIDER_CLASS (klass);
+ GeglSourceClass *source_class = GEGL_SOURCE_CLASS (klass);
gobject_class->constructor = constructor;
gobject_class->set_property = set_property;
gobject_class->get_property = get_property;
- provider_class->command = command;
+ source_class->command = command;
g_object_class_install_property (gobject_class, PROP_STORAGE,
g_param_spec_object ("storage",
Modified: trunk/gegl/buffer/gegl-handler.c
==============================================================================
--- trunk/gegl/buffer/gegl-handler.c (original)
+++ trunk/gegl/buffer/gegl-handler.c Mon Apr 14 23:27:05 2008
@@ -22,12 +22,12 @@
#include <glib-object.h>
-#include "gegl-provider.h"
+#include "gegl-source.h"
#include "gegl-handler.h"
#include "gegl-handlers.h"
-G_DEFINE_TYPE (GeglHandler, gegl_handler, GEGL_TYPE_PROVIDER)
+G_DEFINE_TYPE (GeglHandler, gegl_handler, GEGL_TYPE_SOURCE)
enum
{
@@ -40,24 +40,24 @@
{
GeglHandler *handler = GEGL_HANDLER (object);
- if (handler->provider != NULL)
+ if (handler->source != NULL)
{
- g_object_unref (handler->provider);
- handler->provider = NULL;
+ g_object_unref (handler->source);
+ handler->source = NULL;
}
G_OBJECT_CLASS (gegl_handler_parent_class)->dispose (object);
}
static gpointer
-command (GeglProvider *gegl_provider,
+command (GeglSource *gegl_source,
GeglTileCommand command,
gint x,
gint y,
gint z,
gpointer data)
{
- GeglHandler *handler = (GeglHandler*)gegl_provider;
+ GeglHandler *handler = (GeglHandler*)gegl_source;
return gegl_handler_chain_up (handler, command, x, y, z, data);
}
@@ -73,7 +73,7 @@
switch (property_id)
{
case PROP_SOURCE:
- g_value_set_object (value, handler->provider);
+ g_value_set_object (value, handler->source);
break;
default:
@@ -93,9 +93,9 @@
switch (property_id)
{
case PROP_SOURCE:
- if (handler->provider != NULL)
- g_object_unref (handler->provider);
- handler->provider = GEGL_PROVIDER (g_value_dup_object (value));
+ if (handler->source != NULL)
+ g_object_unref (handler->source);
+ handler->source = GEGL_SOURCE (g_value_dup_object (value));
/* special case if we are the Traits subclass of Trait
* also set the source at the end of the chain.
@@ -108,7 +108,7 @@
iter = iter->next;
if (iter)
{
- g_object_set (GEGL_HANDLER (iter->data), "provider", handler->provider, NULL);
+ g_object_set (GEGL_HANDLER (iter->data), "source", handler->source, NULL);
}
}
return;
@@ -126,26 +126,26 @@
gint z,
gpointer data)
{
- GeglProvider *provider = gegl_handler_get_provider (handler);
- if (provider)
- return gegl_provider_command (provider, command, x, y, z, data);
+ GeglSource *source = gegl_handler_get_source (handler);
+ if (source)
+ return gegl_source_command (source, command, x, y, z, data);
return NULL;
}
static void
gegl_handler_class_init (GeglHandlerClass *klass)
{
- GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
- GeglProviderClass *provider_class = GEGL_PROVIDER_CLASS (klass);
+ GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
+ GeglSourceClass *source_class = GEGL_SOURCE_CLASS (klass);
gobject_class->set_property = set_property;
gobject_class->get_property = get_property;
gobject_class->dispose = dispose;
- provider_class->command = command;
+ source_class->command = command;
g_object_class_install_property (gobject_class, PROP_SOURCE,
- g_param_spec_object ("provider",
+ g_param_spec_object ("source",
"GeglBuffer",
"The tilestore to be a facade for",
G_TYPE_OBJECT,
@@ -155,7 +155,7 @@
static void
gegl_handler_init (GeglHandler *self)
{
- self->provider = NULL;
+ self->source = NULL;
}
Modified: trunk/gegl/buffer/gegl-handler.h
==============================================================================
--- trunk/gegl/buffer/gegl-handler.h (original)
+++ trunk/gegl/buffer/gegl-handler.h Mon Apr 14 23:27:05 2008
@@ -19,7 +19,7 @@
#ifndef __GEGL_HANDLER_H__
#define __GEGL_HANDLER_H__
-#include "gegl-provider.h"
+#include "gegl-source.h"
G_BEGIN_DECLS
@@ -33,19 +33,22 @@
struct _GeglHandler
{
- GeglProvider parent_instance;
+ GeglSource parent_instance;
- GeglProvider *provider;
+ GeglSource *source; /* The source of the data, which we can rely on if
+ our command handler doesn't handle a command, this
+ is typically done with gegl_handler_chain_up passing
+ ourself as the first parameter. */
};
struct _GeglHandlerClass
{
- GeglProviderClass parent_class;
+ GeglSourceClass parent_class;
};
GType gegl_handler_get_type (void) G_GNUC_CONST;
-#define gegl_handler_get_provider(handler) (((GeglHandler*)handler)->provider)
+#define gegl_handler_get_source(handler) (((GeglHandler*)handler)->source)
gpointer gegl_handler_chain_up (GeglHandler *handler,
Modified: trunk/gegl/buffer/gegl-handlers.c
==============================================================================
--- trunk/gegl/buffer/gegl-handlers.c (original)
+++ trunk/gegl/buffer/gegl-handlers.c Mon Apr 14 23:27:05 2008
@@ -85,7 +85,7 @@
}
static gpointer
-command (GeglProvider *tile_store,
+command (GeglSource *tile_store,
GeglTileCommand command,
gint x,
gint y,
@@ -93,13 +93,13 @@
gpointer data)
{
GeglHandlers *handlers = (GeglHandlers *) tile_store;
- GeglProvider *provider = ((GeglHandler *) tile_store)->provider;
+ GeglSource *source = ((GeglHandler *) tile_store)->source;
if (handlers->chain != NULL)
- return gegl_provider_command ((GeglProvider *)(handlers->chain->data),
+ return gegl_source_command ((GeglSource *)(handlers->chain->data),
command, x, y, z, data);
- else if (provider)
- return gegl_provider_command (provider, command, x, y, z, data);
+ else if (source)
+ return gegl_source_command (source, command, x, y, z, data);
else
g_assert (0);
@@ -110,10 +110,10 @@
gegl_handlers_class_init (GeglHandlersClass *class)
{
GObjectClass *gobject_class;
- GeglProviderClass *tile_store_class;
+ GeglSourceClass *tile_store_class;
gobject_class = (GObjectClass *) class;
- tile_store_class = (GeglProviderClass *) class;
+ tile_store_class = (GeglSourceClass *) class;
tile_store_class->command = command;
@@ -138,19 +138,19 @@
while (iter)
{
GeglHandler *handler;
- GeglProvider *provider = NULL;
+ GeglSource *source = NULL;
handler = iter->data;
if (iter->next)
{
- provider = g_object_ref (iter->next->data);
+ source = g_object_ref (iter->next->data);
}
else
{
- g_object_get (handlers, "provider", &provider, NULL);
+ g_object_get (handlers, "source", &source, NULL);
}
- g_object_set (G_OBJECT (handler), "provider", provider, NULL);
- g_object_unref (provider);
+ g_object_set (G_OBJECT (handler), "source", source, NULL);
+ g_object_unref (source);
iter = iter->next;
}
}
Modified: trunk/gegl/buffer/gegl-handlers.h
==============================================================================
--- trunk/gegl/buffer/gegl-handlers.h (original)
+++ trunk/gegl/buffer/gegl-handlers.h Mon Apr 14 23:27:05 2008
@@ -48,7 +48,7 @@
* @handler: a #GeglHandler.
*
* Adds @handler to the list of handlers to be processed, the order handlers
- * are added in is from original provider to last processing element, commands
+ * are added in is from original source to last processing element, commands
* are passed from the last added to the first one in the chain, tiles
* and other results are passed back up
*
Copied: trunk/gegl/buffer/gegl-source.c (from r2168, /trunk/gegl/buffer/gegl-provider.c)
==============================================================================
--- /trunk/gegl/buffer/gegl-provider.c (original)
+++ trunk/gegl/buffer/gegl-source.c Mon Apr 14 23:27:05 2008
@@ -17,12 +17,12 @@
*/
#include <glib.h>
#include <glib-object.h>
-#include "gegl-provider.h"
+#include "gegl-source.h"
-G_DEFINE_TYPE (GeglProvider, gegl_provider, G_TYPE_OBJECT)
+G_DEFINE_TYPE (GeglSource, gegl_source, G_TYPE_OBJECT)
static gpointer
-command (GeglProvider *gegl_provider,
+command (GeglSource *gegl_source,
GeglTileCommand command,
gint x,
gint y,
@@ -34,28 +34,28 @@
}
static void
-gegl_provider_class_init (GeglProviderClass *klass)
+gegl_source_class_init (GeglSourceClass *klass)
{
klass->command = command;
}
static void
-gegl_provider_init (GeglProvider *self)
+gegl_source_init (GeglSource *self)
{
}
gpointer
-gegl_provider_command (GeglProvider *gegl_provider,
+gegl_source_command (GeglSource *gegl_source,
GeglTileCommand command,
gint x,
gint y,
gint z,
gpointer data)
{
- GeglProviderClass *klass;
+ GeglSourceClass *klass;
- klass = GEGL_PROVIDER_GET_CLASS (gegl_provider);
+ klass = GEGL_SOURCE_GET_CLASS (gegl_source);
- return klass->command (gegl_provider, command, x, y, z, data);
+ return klass->command (gegl_source, command, x, y, z, data);
}
Copied: trunk/gegl/buffer/gegl-source.h (from r2168, /trunk/gegl/buffer/gegl-provider.h)
==============================================================================
--- /trunk/gegl/buffer/gegl-provider.h (original)
+++ trunk/gegl/buffer/gegl-source.h Mon Apr 14 23:27:05 2008
@@ -16,8 +16,8 @@
* Copyright 2006 Ãyvind KolÃs <pippin gimp org>
*/
-#ifndef __GEGL_PROVIDER_H__
-#define __GEGL_PROVIDER_H__
+#ifndef __GEGL_SOURCE_H__
+#define __GEGL_SOURCE_H__
#include <glib-object.h>
#include <babl/babl.h>
@@ -26,12 +26,12 @@
G_BEGIN_DECLS
-#define GEGL_TYPE_PROVIDER (gegl_provider_get_type ())
-#define GEGL_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEGL_TYPE_PROVIDER, GeglProvider))
-#define GEGL_PROVIDER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GEGL_TYPE_PROVIDER, GeglProviderClass))
-#define GEGL_IS_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEGL_TYPE_PROVIDER))
-#define GEGL_IS_PROVIDER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GEGL_TYPE_PROVIDER))
-#define GEGL_PROVIDER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GEGL_TYPE_PROVIDER, GeglProviderClass))
+#define GEGL_TYPE_SOURCE (gegl_source_get_type ())
+#define GEGL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEGL_TYPE_SOURCE, GeglSource))
+#define GEGL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GEGL_TYPE_SOURCE, GeglSourceClass))
+#define GEGL_IS_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEGL_TYPE_SOURCE))
+#define GEGL_IS_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GEGL_TYPE_SOURCE))
+#define GEGL_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GEGL_TYPE_SOURCE, GeglSourceClass))
typedef gint GeglTileCommand;
@@ -51,16 +51,16 @@
GEGL_TILE_LAST_COMMAND
};
-struct _GeglProvider
+struct _GeglSource
{
GObject parent_instance;
};
-struct _GeglProviderClass
+struct _GeglSourceClass
{
GObjectClass parent_class;
- gpointer (*command) (GeglProvider *gegl_provider,
+ gpointer (*command) (GeglSource *gegl_source,
GeglTileCommand command,
gint x,
gint y,
@@ -68,39 +68,39 @@
gpointer data);
};
-GType gegl_provider_get_type (void) G_GNUC_CONST;
+GType gegl_source_get_type (void) G_GNUC_CONST;
-gpointer gegl_provider_command (GeglProvider *gegl_provider,
+gpointer gegl_source_command (GeglSource *gegl_source,
GeglTileCommand command,
gint x,
gint y,
gint z,
gpointer data);
-#define gegl_provider_idle(provider) \
- gegl_provider_command(provider,GEGL_TILE_IDLE,0,0,0,NULL)
-#define gegl_provider_set_tile(provider,x,y,z,tile) \
- (gboolean)gegl_provider_command(provider,GEGL_TILE_SET,x,y,z,tile)
-#define gegl_provider_get_tile(provider,x,y,z) \
- (GeglTile*)gegl_provider_command(provider,GEGL_TILE_GET,x,y,z,NULL)
-#define gegl_provider_is_cached(provider,x,y,z) \
- (gboolean)gegl_provider_command(provider,GEGL_TILE_IS_CACHED,x,y,z,NULL)
-#define gegl_provider_exist(provider,x,y,z) \
- (gboolean)gegl_provider_command(provider,GEGL_TILE_EXIST,x,y,z,NULL)
-#define gegl_provider_void(provider,x,y,z) \
- gegl_provider_command(provider,GEGL_TILE_VOID,x,y,z,NULL)
-#define gegl_provider_void_tl(provider,x,y,z) \
- gegl_provider_command(provider,GEGL_TILE_VOID_TL,x,y,z,NULL)
-#define gegl_provider_void_tr(provider,x,y,z) \
- gegl_provider_command(provider,GEGL_TILE_VOID_TR,x,y,z,NULL)
-#define gegl_provider_void_bl(provider,x,y,z) \
- gegl_provider_command(provider,GEGL_TILE_VOID_BL,x,y,z,NULL)
-#define gegl_provider_void_br(provider,x,y,z) \
- gegl_provider_command(provider,GEGL_TILE_VOID_BR,x,y,z,NULL)
-#define gegl_provider_undo_start_group(provider,x,y,z) \
- gegl_provider_command(provider,GEGL_TILE_UNDO_START_GROUP,x,y,z,NULL)
+#define gegl_source_idle(source) \
+ gegl_source_command(source,GEGL_TILE_IDLE,0,0,0,NULL)
+#define gegl_source_set_tile(source,x,y,z,tile) \
+ (gboolean)gegl_source_command(source,GEGL_TILE_SET,x,y,z,tile)
+#define gegl_source_get_tile(source,x,y,z) \
+ (GeglTile*)gegl_source_command(source,GEGL_TILE_GET,x,y,z,NULL)
+#define gegl_source_is_cached(source,x,y,z) \
+ (gboolean)gegl_source_command(source,GEGL_TILE_IS_CACHED,x,y,z,NULL)
+#define gegl_source_exist(source,x,y,z) \
+ (gboolean)gegl_source_command(source,GEGL_TILE_EXIST,x,y,z,NULL)
+#define gegl_source_void(source,x,y,z) \
+ gegl_source_command(source,GEGL_TILE_VOID,x,y,z,NULL)
+#define gegl_source_void_tl(source,x,y,z) \
+ gegl_source_command(source,GEGL_TILE_VOID_TL,x,y,z,NULL)
+#define gegl_source_void_tr(source,x,y,z) \
+ gegl_source_command(source,GEGL_TILE_VOID_TR,x,y,z,NULL)
+#define gegl_source_void_bl(source,x,y,z) \
+ gegl_source_command(source,GEGL_TILE_VOID_BL,x,y,z,NULL)
+#define gegl_source_void_br(source,x,y,z) \
+ gegl_source_command(source,GEGL_TILE_VOID_BR,x,y,z,NULL)
+#define gegl_source_undo_start_group(source,x,y,z) \
+ gegl_source_command(source,GEGL_TILE_UNDO_START_GROUP,x,y,z,NULL)
G_END_DECLS
Modified: trunk/gegl/buffer/gegl-storage.c
==============================================================================
--- trunk/gegl/buffer/gegl-storage.c (original)
+++ trunk/gegl/buffer/gegl-storage.c Mon Apr 14 23:27:05 2008
@@ -160,7 +160,7 @@
return FALSE;
}
- gegl_provider_idle (GEGL_PROVIDER (storage));
+ gegl_source_idle (GEGL_SOURCE (storage));
return TRUE;
}
@@ -187,7 +187,7 @@
{
#if 0
g_object_set (storage,
- "provider", g_object_new (GEGL_TYPE_TILE_DISK,
+ "source", g_object_new (GEGL_TYPE_TILE_DISK,
"tile-width", storage->tile_width,
"tile-height", storage->tile_height,
"format", storage->format,
@@ -196,7 +196,7 @@
NULL);
#else
g_object_set (storage,
- "provider", g_object_new (GEGL_TYPE_TILE_GIO,
+ "source", g_object_new (GEGL_TYPE_TILE_GIO,
"tile-width", storage->tile_width,
"tile-height", storage->tile_height,
"format", storage->format,
@@ -208,7 +208,7 @@
else
{
g_object_set (storage,
- "provider", g_object_new (GEGL_TYPE_TILE_MEM,
+ "source", g_object_new (GEGL_TYPE_TILE_MEM,
"tile-width", storage->tile_width,
"tile-height", storage->tile_height,
"format", storage->format,
@@ -216,7 +216,7 @@
NULL);
}
- g_object_get (handler->provider,
+ g_object_get (handler->source,
"tile-size", &storage->tile_size,
"px-size", &storage->px_size,
NULL);
@@ -238,7 +238,7 @@
if (1) gegl_handlers_add (handlers, g_object_new (GEGL_TYPE_HANDLER_ZOOM,
- "backend", handler->provider,
+ "backend", handler->source,
"storage", storage,
NULL));
@@ -250,7 +250,7 @@
* gegl-storage for each tile.
*/
if (1) gegl_handlers_add (handlers, g_object_new (GEGL_TYPE_HANDLER_EMPTY,
- "backend", handler->provider,
+ "backend", handler->source,
NULL));
if (g_getenv("GEGL_LOG_TILE_EMPTY"))
gegl_handlers_add (handlers, g_object_new (GEGL_TYPE_HANDLER_LOG, NULL));
Modified: trunk/gegl/buffer/gegl-tile-backend.c
==============================================================================
--- trunk/gegl/buffer/gegl-tile-backend.c (original)
+++ trunk/gegl/buffer/gegl-tile-backend.c Mon Apr 14 23:27:05 2008
@@ -20,10 +20,10 @@
#include <string.h>
#include <babl/babl.h>
-#include "gegl-provider.h"
+#include "gegl-source.h"
#include "gegl-tile-backend.h"
-G_DEFINE_TYPE (GeglTileBackend, gegl_tile_backend, GEGL_TYPE_PROVIDER)
+G_DEFINE_TYPE (GeglTileBackend, gegl_tile_backend, GEGL_TYPE_SOURCE)
static GObjectClass * parent_class = NULL;
enum
Modified: trunk/gegl/buffer/gegl-tile-backend.h
==============================================================================
--- trunk/gegl/buffer/gegl-tile-backend.h (original)
+++ trunk/gegl/buffer/gegl-tile-backend.h Mon Apr 14 23:27:05 2008
@@ -19,7 +19,7 @@
#ifndef __GEGL_TILE_BACKEND_H__
#define __GEGL_TILE_BACKEND_H__
-#include "gegl-provider.h"
+#include "gegl-source.h"
G_BEGIN_DECLS
@@ -32,18 +32,18 @@
struct _GeglTileBackend
{
- GeglProvider parent_instance;
+ GeglSource parent_instance;
- gint tile_width;
- gint tile_height;
- Babl *format; /* defaults to the babl format "R'G'B'A u8" */
- gint px_size; /* size of a single pixel in bytes */
- gint tile_size; /* size of an entire tile in bytes */
+ gint tile_width;
+ gint tile_height;
+ Babl *format; /* defaults to the babl format "R'G'B'A u8" */
+ gint px_size; /* size of a single pixel in bytes */
+ gint tile_size; /* size of an entire tile in bytes */
};
struct _GeglTileBackendClass
{
- GeglProviderClass parent_class;
+ GeglSourceClass parent_class;
};
GType gegl_tile_backend_get_type (void) G_GNUC_CONST;
Modified: trunk/gegl/buffer/gegl-tile-disk.c
==============================================================================
--- trunk/gegl/buffer/gegl-tile-disk.c (original)
+++ trunk/gegl/buffer/gegl-tile-disk.c Mon Apr 14 23:27:05 2008
@@ -243,10 +243,10 @@
* too often.
*/
static GeglTile *
-get_tile (GeglProvider *tile_store,
- gint x,
- gint y,
- gint z)
+get_tile (GeglSource *tile_store,
+ gint x,
+ gint y,
+ gint z)
{
GeglTileDisk *tile_disk = GEGL_TILE_DISK (tile_store);
GeglTileBackend *backend = GEGL_TILE_BACKEND (tile_store);
@@ -268,11 +268,11 @@
}
static gpointer
-set_tile (GeglProvider *store,
- GeglTile *tile,
- gint x,
- gint y,
- gint z)
+set_tile (GeglSource *store,
+ GeglTile *tile,
+ gint x,
+ gint y,
+ gint z)
{
GeglTileBackend *backend = GEGL_TILE_BACKEND (store);
GeglTileDisk *tile_disk = GEGL_TILE_DISK (backend);
@@ -297,11 +297,11 @@
}
static gpointer
-void_tile (GeglProvider *store,
- GeglTile *tile,
- gint x,
- gint y,
- gint z)
+void_tile (GeglSource *store,
+ GeglTile *tile,
+ gint x,
+ gint y,
+ gint z)
{
GeglTileBackend *backend = GEGL_TILE_BACKEND (store);
GeglTileDisk *tile_disk = GEGL_TILE_DISK (backend);
@@ -316,11 +316,11 @@
}
static gpointer
-exist_tile (GeglProvider *store,
- GeglTile *tile,
- gint x,
- gint y,
- gint z)
+exist_tile (GeglSource *store,
+ GeglTile *tile,
+ gint x,
+ gint y,
+ gint z)
{
GeglTileBackend *backend = GEGL_TILE_BACKEND (store);
GeglTileDisk *tile_disk = GEGL_TILE_DISK (backend);
@@ -336,7 +336,7 @@
};
static gpointer
-command (GeglProvider *tile_store,
+command (GeglSource *tile_store,
GeglTileCommand command,
gint x,
gint y,
@@ -497,8 +497,8 @@
static void
gegl_tile_disk_class_init (GeglTileDiskClass *klass)
{
- GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
- GeglProviderClass *gegl_provider_class = GEGL_PROVIDER_CLASS (klass);
+ GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
+ GeglSourceClass *gegl_source_class = GEGL_SOURCE_CLASS (klass);
parent_class = g_type_class_peek_parent (klass);
@@ -507,7 +507,7 @@
gobject_class->constructor = gegl_tile_disk_constructor;
gobject_class->finalize = finalize;
- gegl_provider_class->command = command;
+ gegl_source_class->command = command;
g_object_class_install_property (gobject_class, PROP_PATH,
Modified: trunk/gegl/buffer/gegl-tile-gio.c
==============================================================================
--- trunk/gegl/buffer/gegl-tile-gio.c (original)
+++ trunk/gegl/buffer/gegl-tile-gio.c Mon Apr 14 23:27:05 2008
@@ -78,11 +78,11 @@
};
static gboolean
-exist_tile (GeglProvider *store,
- GeglTile *tile,
- gint x,
- gint y,
- gint z);
+exist_tile (GeglSource *store,
+ GeglTile *tile,
+ gint x,
+ gint y,
+ gint z);
static GFile *make_tile_file (GeglTileGio *gio,
gint x,
@@ -157,10 +157,10 @@
* too often.
*/
static GeglTile *
-get_tile (GeglProvider *tile_store,
- gint x,
- gint y,
- gint z)
+get_tile (GeglSource *tile_store,
+ gint x,
+ gint y,
+ gint z)
{
GeglTileGio *tile_gio = GEGL_TILE_GIO (tile_store);
GeglTileBackend *backend = GEGL_TILE_BACKEND (tile_store);
@@ -181,11 +181,11 @@
}
static gpointer
-set_tile (GeglProvider *store,
- GeglTile *tile,
- gint x,
- gint y,
- gint z)
+set_tile (GeglSource *store,
+ GeglTile *tile,
+ gint x,
+ gint y,
+ gint z)
{
GeglTileBackend *backend = GEGL_TILE_BACKEND (store);
GeglTileGio *tile_gio = GEGL_TILE_GIO (backend);
@@ -201,11 +201,11 @@
}
static gpointer
-void_tile (GeglProvider *store,
- GeglTile *tile,
- gint x,
- gint y,
- gint z)
+void_tile (GeglSource *store,
+ GeglTile *tile,
+ gint x,
+ gint y,
+ gint z)
{
GeglTileBackend *backend = GEGL_TILE_BACKEND (store);
GeglTileGio *gio = GEGL_TILE_GIO (backend);
@@ -218,11 +218,11 @@
}
static gboolean
-exist_tile (GeglProvider *store,
- GeglTile *tile,
- gint x,
- gint y,
- gint z)
+exist_tile (GeglSource *store,
+ GeglTile *tile,
+ gint x,
+ gint y,
+ gint z)
{
GeglTileBackend *backend = GEGL_TILE_BACKEND (store);
GeglTileGio *gio = GEGL_TILE_GIO (backend);
@@ -251,7 +251,7 @@
};
static gpointer
-command (GeglProvider *tile_store,
+command (GeglSource *tile_store,
GeglTileCommand command,
gint x,
gint y,
@@ -355,8 +355,8 @@
static void
gegl_tile_gio_class_init (GeglTileGioClass *klass)
{
- GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
- GeglProviderClass *gegl_provider_class = GEGL_PROVIDER_CLASS (klass);
+ GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
+ GeglSourceClass *gegl_source_class = GEGL_SOURCE_CLASS (klass);
parent_class = g_type_class_peek_parent (klass);
@@ -365,7 +365,7 @@
gobject_class->constructor = gegl_tile_gio_constructor;
gobject_class->finalize = finalize;
- gegl_provider_class->command = command;
+ gegl_source_class->command = command;
g_object_class_install_property (gobject_class, PROP_PATH,
Modified: trunk/gegl/buffer/gegl-tile-mem.c
==============================================================================
--- trunk/gegl/buffer/gegl-tile-mem.c (original)
+++ trunk/gegl/buffer/gegl-tile-mem.c Mon Apr 14 23:27:05 2008
@@ -135,10 +135,10 @@
* too often.
*/
static GeglTile *
-get_tile (GeglProvider *tile_store,
- gint x,
- gint y,
- gint z)
+get_tile (GeglSource *tile_store,
+ gint x,
+ gint y,
+ gint z)
{
GeglTileMem *tile_mem = GEGL_TILE_MEM (tile_store);
GeglTileBackend *backend = GEGL_TILE_BACKEND (tile_store);
@@ -160,11 +160,11 @@
}
static
-gboolean set_tile (GeglProvider *store,
- GeglTile *tile,
- gint x,
- gint y,
- gint z)
+gboolean set_tile (GeglSource *store,
+ GeglTile *tile,
+ gint x,
+ gint y,
+ gint z)
{
GeglTileBackend *backend = GEGL_TILE_BACKEND (store);
GeglTileMem *tile_mem = GEGL_TILE_MEM (backend);
@@ -188,11 +188,11 @@
}
static
-gboolean void_tile (GeglProvider *store,
- GeglTile *tile,
- gint x,
- gint y,
- gint z)
+gboolean void_tile (GeglSource *store,
+ GeglTile *tile,
+ gint x,
+ gint y,
+ gint z)
{
GeglTileBackend *backend = GEGL_TILE_BACKEND (store);
GeglTileMem *tile_mem = GEGL_TILE_MEM (backend);
@@ -207,11 +207,11 @@
}
static
-gboolean exist_tile (GeglProvider *store,
- GeglTile *tile,
- gint x,
- gint y,
- gint z)
+gboolean exist_tile (GeglSource *store,
+ GeglTile *tile,
+ gint x,
+ gint y,
+ gint z)
{
GeglTileBackend *backend = GEGL_TILE_BACKEND (store);
GeglTileMem *tile_mem = GEGL_TILE_MEM (backend);
@@ -227,7 +227,7 @@
};
static gpointer
-command (GeglProvider *tile_store,
+command (GeglSource *tile_store,
GeglTileCommand command,
gint x,
gint y,
@@ -260,10 +260,10 @@
return FALSE;
}
-static void set_property (GObject *object,
- guint property_id,
- const GValue *value,
- GParamSpec *pspec)
+static void set_property (GObject *object,
+ guint property_id,
+ const GValue *value,
+ GParamSpec *pspec)
{
switch (property_id)
{
@@ -274,9 +274,9 @@
}
static void get_property (GObject *object,
- guint property_id,
- GValue *value,
- GParamSpec *pspec)
+ guint property_id,
+ GValue *value,
+ GParamSpec *pspec)
{
switch (property_id)
{
@@ -355,8 +355,8 @@
static void
gegl_tile_mem_class_init (GeglTileMemClass *klass)
{
- GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
- GeglProviderClass *gegl_provider_class = GEGL_PROVIDER_CLASS (klass);
+ GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
+ GeglSourceClass *gegl_source_class = GEGL_SOURCE_CLASS (klass);
parent_class = g_type_class_peek_parent (klass);
@@ -365,7 +365,7 @@
gobject_class->constructor = gegl_tile_mem_constructor;
gobject_class->finalize = finalize;
- gegl_provider_class->command = command;
+ gegl_source_class->command = command;
}
static void
Modified: trunk/gegl/buffer/gegl-tile.c
==============================================================================
--- trunk/gegl/buffer/gegl-tile.c (original)
+++ trunk/gegl/buffer/gegl-tile.c Mon Apr 14 23:27:05 2008
@@ -31,7 +31,7 @@
#include "gegl-buffer.h"
#include "gegl-buffer-private.h"
#include "gegl-tile.h"
-#include "gegl-provider.h"
+#include "gegl-source.h"
G_DEFINE_TYPE (GeglTile, gegl_tile, G_TYPE_OBJECT)
@@ -284,29 +284,29 @@
x /= 2;
y /= 2;
- gegl_provider_void (GEGL_PROVIDER (tile->storage), x, y, z);
+ gegl_source_void (GEGL_SOURCE (tile->storage), x, y, z);
#if 0
/* FIXME: reenable this code */
if (!ver)
{
if (!hor)
{
- gegl_provider_void_tl (GEGL_PROVIDER (tile->storage), x,y,z);
+ gegl_source_void_tl (GEGL_SOURCE (tile->storage), x,y,z);
}
else
{
- gegl_provider_void_tr (GEGL_PROVIDER (tile->storage), x,y,z);
+ gegl_source_void_tr (GEGL_SOURCE (tile->storage), x,y,z);
}
}
else
{
if (!hor)
{
- gegl_provider_void_bl (GEGL_PROVIDER (tile->storage), x,y,z);
+ gegl_source_void_bl (GEGL_SOURCE (tile->storage), x,y,z);
}
else
{
- gegl_provider_void_br (GEGL_PROVIDER (tile->storage), x,y,z);
+ gegl_source_void_br (GEGL_SOURCE (tile->storage), x,y,z);
}
}
#endif
@@ -397,10 +397,10 @@
{
if (tile->storage == NULL)
return FALSE;
- return gegl_provider_set_tile (GEGL_PROVIDER (tile->storage),
- tile->storage_x,
- tile->storage_y,
- tile->storage_z, tile);
+ return gegl_source_set_tile (GEGL_SOURCE (tile->storage),
+ tile->storage_x,
+ tile->storage_y,
+ tile->storage_z, tile);
}
/* compute the tile indice of a coordinate
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
--- trunk/gegl/buffer/gegl-buffer-private.h (original)
+++ trunk/gegl/buffer/gegl-buffer-private.h Mon Apr 14 23:27:05 2008
@@ -30,7 +30,7 @@
struct _GeglBuffer
{
GeglHandlers parent_instance; /* which is a GeglHandler which has a
- provider field which is used for chaining
+ source field which is used for chaining
sub buffers with their anchestors */
GeglRectangle extent; /* the dimensions of the buffer */
@@ -40,7 +40,7 @@
gint shift_x; /* The relative offset of origins compared with */
gint shift_y; /* anchestral storage buffer, during */
/* construction relative to immediate provider */
GeglRectangle abyss;
Modified: trunk/gegl/buffer/gegl-buffer-save.c
==============================================================================
@@ -40,7 +40,7 @@
gint shift_x; /* The relative offset of origins compared with */
gint shift_y; /* anchestral storage buffer, during */
- /* construction relative to immediate provider */
+ /* construction relative to immediate source */
GeglRectangle abyss;
Modified: trunk/gegl/buffer/gegl-buffer-save.c
--- trunk/gegl/buffer/gegl-buffer.c (original)
+++ trunk/gegl/buffer/gegl-buffer.c Mon Apr 14 23:27:05 2008
@@ -233,12 +233,12 @@
gegl_buffer_sample_cleanup (buffer);
- if (handler->provider &&
- GEGL_IS_BUFFER_ALLOCATOR (handler->provider))
+ if (handler->source &&
+ GEGL_IS_BUFFER_ALLOCATOR (handler->source))
{
gegl_buffer_void (buffer);
#if 0
- handler->provider = NULL; /* this might be a dangerous way of marking that we have already voided */
+ handler->source = NULL; /* this might be a dangerous way of marking that we have already voided */
#endif
}
@@ -257,14 +257,14 @@
static GeglTileBackend *
gegl_buffer_backend (GeglBuffer *buffer)
{
- GeglProvider *tmp = GEGL_PROVIDER (buffer);
+ GeglSource *tmp = GEGL_SOURCE (buffer);
if (!tmp)
return NULL;
do
{
- tmp = GEGL_HANDLER (tmp)->provider;
+ tmp = GEGL_HANDLER (tmp)->source;
} while (tmp &&
/*GEGL_IS_TILE_TRAIT (tmp) &&*/
!GEGL_IS_TILE_BACKEND (tmp));
@@ -278,11 +278,11 @@
static GeglStorage *
gegl_buffer_storage (GeglBuffer *buffer)
{
- GeglProvider *tmp = GEGL_PROVIDER (buffer);
+ GeglSource *tmp = GEGL_SOURCE (buffer);
do
{
- tmp = ((GeglHandler *) (tmp))->provider;
+ tmp = ((GeglHandler *) (tmp))->source;
} while (!GEGL_IS_STORAGE (tmp));
return (GeglStorage *) tmp;
@@ -300,7 +300,7 @@
GeglHandlers *handlers;
GeglTileBackend *backend;
GeglHandler *handler;
- GeglProvider *provider;
+ GeglSource *source;
gint tile_width;
gint tile_height;
@@ -309,27 +309,27 @@
buffer = GEGL_BUFFER (object);
handlers = GEGL_HANDLERS (object);
handler = GEGL_HANDLER (object);
- provider = handler->provider;
+ source = handler->source;
backend = gegl_buffer_backend (buffer);
- if (provider)
+ if (source)
{
- if (GEGL_IS_STORAGE (provider))
- buffer->format = GEGL_STORAGE (provider)->format;
- else if (GEGL_IS_BUFFER (provider))
- buffer->format = GEGL_BUFFER (provider)->format;
+ if (GEGL_IS_STORAGE (source))
+ buffer->format = GEGL_STORAGE (source)->format;
+ else if (GEGL_IS_BUFFER (source))
+ buffer->format = GEGL_BUFFER (source)->format;
}
- if (!provider)
+ if (!source)
{
- /* if no provider is specified if a format is specified, we
+ /* if no source is specified if a format is specified, we
* we need to create our own
* provider (this adds a redirectin buffer in between for
* all "allocated from format", type buffers.
*/
g_assert (buffer->format);
- provider = GEGL_PROVIDER (gegl_buffer_new_from_format (buffer->format,
+ source = GEGL_SOURCE (gegl_buffer_new_from_format (buffer->format,
buffer->extent.x,
buffer->extent.y,
buffer->extent.width,
@@ -338,12 +338,12 @@
* the top level behavior exhibited by this buffer object.
*/
g_object_set (buffer,
- "provider", provider,
+ "source", source,
NULL);
- g_object_unref (provider);
+ g_object_unref (source);
- g_assert (provider);
- backend = gegl_buffer_backend (GEGL_BUFFER (provider));
+ g_assert (source);
+ backend = gegl_buffer_backend (GEGL_BUFFER (source));
g_assert (backend);
}
@@ -353,21 +353,21 @@
tile_height = backend->tile_height;
if (buffer->extent.width == -1 &&
- buffer->extent.height == -1) /* no specified extents, inheriting from provider */
+ buffer->extent.height == -1) /* no specified extents, inheriting from source */
{
- if (GEGL_IS_BUFFER (provider))
+ if (GEGL_IS_BUFFER (source))
{
- buffer->extent.x = GEGL_BUFFER (provider)->extent.x;
- buffer->extent.y = GEGL_BUFFER (provider)->extent.y;
- buffer->extent.width = GEGL_BUFFER (provider)->extent.width;
- buffer->extent.height = GEGL_BUFFER (provider)->extent.height;
+ buffer->extent.x = GEGL_BUFFER (source)->extent.x;
+ buffer->extent.y = GEGL_BUFFER (source)->extent.y;
+ buffer->extent.width = GEGL_BUFFER (source)->extent.width;
+ buffer->extent.height = GEGL_BUFFER (source)->extent.height;
}
- else if (GEGL_IS_STORAGE (provider))
+ else if (GEGL_IS_STORAGE (source))
{
buffer->extent.x = 0;
buffer->extent.y = 0;
- buffer->extent.width = GEGL_STORAGE (provider)->width;
- buffer->extent.height = GEGL_STORAGE (provider)->height;
+ buffer->extent.width = GEGL_STORAGE (source)->width;
+ buffer->extent.height = GEGL_STORAGE (source)->height;
}
}
@@ -394,21 +394,21 @@
else if (buffer->abyss.width == -1 ||
buffer->abyss.height == -1)
{
- buffer->abyss.x = GEGL_BUFFER (provider)->abyss.x - buffer->shift_x;
- buffer->abyss.y = GEGL_BUFFER (provider)->abyss.y - buffer->shift_y;
- buffer->abyss.width = GEGL_BUFFER (provider)->abyss.width;
- buffer->abyss.height = GEGL_BUFFER (provider)->abyss.height;
+ buffer->abyss.x = GEGL_BUFFER (source)->abyss.x - buffer->shift_x;
+ buffer->abyss.y = GEGL_BUFFER (source)->abyss.y - buffer->shift_y;
+ buffer->abyss.width = GEGL_BUFFER (source)->abyss.width;
+ buffer->abyss.height = GEGL_BUFFER (source)->abyss.height;
}
/* intersect our own abyss with parent's abyss if it exists
*/
- if (GEGL_IS_BUFFER (provider))
+ if (GEGL_IS_BUFFER (source))
{
GeglRectangle parent = {
- GEGL_BUFFER (provider)->abyss.x - buffer->shift_x,
- GEGL_BUFFER (provider)->abyss.y - buffer->shift_y,
- GEGL_BUFFER (provider)->abyss.width,
- GEGL_BUFFER (provider)->abyss.height
+ GEGL_BUFFER (source)->abyss.x - buffer->shift_x,
+ GEGL_BUFFER (source)->abyss.y - buffer->shift_y,
+ GEGL_BUFFER (source)->abyss.width,
+ GEGL_BUFFER (source)->abyss.height
};
GeglRectangle request = {
buffer->abyss.x,
@@ -426,14 +426,14 @@
}
/* compute our own total shift <- this should probably happen approximatly first */
- if (GEGL_IS_BUFFER (provider))
+ if (GEGL_IS_BUFFER (source))
{
- GeglBuffer *provider_buf;
+ GeglBuffer *source_buf;
- provider_buf = GEGL_BUFFER (provider);
+ source_buf = GEGL_BUFFER (source);
- buffer->shift_x += provider_buf->shift_x;
- buffer->shift_y += provider_buf->shift_y;
+ buffer->shift_x += source_buf->shift_x;
+ buffer->shift_y += source_buf->shift_y;
}
else
{
@@ -461,20 +461,20 @@
}
static GeglTile *
-get_tile (GeglProvider *buffer,
- gint x,
- gint y,
- gint z)
+get_tile (GeglSource *buffer,
+ gint x,
+ gint y,
+ gint z)
{
GeglHandlers *handlers = (GeglHandlers*)(buffer);
- GeglProvider *provider = ((GeglHandler*)buffer)->provider;
+ GeglSource *source = ((GeglHandler*)buffer)->source;
GeglTile *tile = NULL;
if (handlers->chain != NULL)
- tile = gegl_provider_get_tile ((GeglProvider*)(handlers->chain->data),
+ tile = gegl_source_get_tile ((GeglSource*)(handlers->chain->data),
x, y, z);
- else if (provider)
- tile = gegl_provider_get_tile (provider, x, y, z);
+ else if (source)
+ tile = gegl_source_get_tile (source, x, y, z);
else
g_assert (0);
@@ -512,7 +512,7 @@
static gpointer
-command (GeglProvider *buffer,
+command (GeglSource *buffer,
GeglTileCommand command,
gint x,
gint y,
@@ -528,14 +528,14 @@
gegl_buffer_class_init (GeglBufferClass *class)
{
GObjectClass *gobject_class = G_OBJECT_CLASS (class);
- GeglProviderClass *tile_provider_class = GEGL_PROVIDER_CLASS (class);
+ GeglSourceClass *tile_source_class = GEGL_SOURCE_CLASS (class);
parent_class = g_type_class_peek_parent (class);
gobject_class->dispose = gegl_buffer_dispose;
gobject_class->constructor = gegl_buffer_constructor;
gobject_class->set_property = set_property;
gobject_class->get_property = get_property;
- tile_provider_class->command = command;
+ tile_source_class->command = command;
g_object_class_install_property (gobject_class, PROP_PX_SIZE,
g_param_spec_int ("px-size", "pixel-size", "size of a single pixel in bytes.",
@@ -556,12 +556,12 @@
G_PARAM_READWRITE |
G_PARAM_CONSTRUCT_ONLY));
g_object_class_install_property (gobject_class, PROP_X,
- g_param_spec_int ("x", "x", "local origin's offset relative to provider origin",
+ g_param_spec_int ("x", "x", "local origin's offset relative to source origin",
G_MININT, G_MAXINT, 0,
G_PARAM_READWRITE |
G_PARAM_CONSTRUCT_ONLY));
g_object_class_install_property (gobject_class, PROP_Y,
- g_param_spec_int ("y", "y", "local origin's offset relative to provider origin",
+ g_param_spec_int ("y", "y", "local origin's offset relative to source origin",
G_MININT, G_MAXINT, 0,
G_PARAM_READWRITE |
G_PARAM_CONSTRUCT_ONLY));
@@ -671,7 +671,7 @@
if (z != 0 ||
tx >= buffer->min_x)
- gegl_provider_command (GEGL_PROVIDER (buffer),
+ gegl_source_command (GEGL_SOURCE (buffer),
GEGL_TILE_VOID, tx, ty, z, NULL);
if (z != 0 ||
@@ -748,7 +748,7 @@
gint tiledy = buffer_y + buffer->shift_y + y;
gint tiledx = buffer_x + buffer->shift_x + x;
- GeglTile *tile = gegl_provider_get_tile ((GeglProvider *) (buffer),
+ GeglTile *tile = gegl_source_get_tile ((GeglSource *) (buffer),
gegl_tile_indice (tiledx, tile_width),
gegl_tile_indice (tiledy, tile_height),
0);
@@ -833,7 +833,7 @@
g_object_unref (buffer->hot_tile);
buffer->hot_tile = NULL;
}
- tile = gegl_provider_get_tile ((GeglProvider *) (buffer),
+ tile = gegl_source_get_tile ((GeglSource *) (buffer),
indice_x, indice_y,
0);
}
@@ -918,7 +918,7 @@
g_object_unref (buffer->hot_tile);
buffer->hot_tile = NULL;
}
- tile = gegl_provider_get_tile ((GeglProvider *) (buffer),
+ tile = gegl_source_get_tile ((GeglSource *) (buffer),
indice_x, indice_y,
0);
}
@@ -1086,7 +1086,7 @@
else
{
guchar *tile_base, *tp;
- GeglTile *tile = gegl_provider_get_tile ((GeglProvider *) (buffer),
+ GeglTile *tile = gegl_source_get_tile ((GeglSource *) (buffer),
gegl_tile_indice (tiledx, tile_width),
gegl_tile_indice (tiledy, tile_height),
level);
@@ -1230,7 +1230,7 @@
if (format == NULL)
format = buffer->format;
- /* FIXME: go through chain of providers up to but not including
+ /* FIXME: go through chain of sources up to but not including
* storage and disassociated Sampler */
if (rect && rect->width == 1 && rect->height == 1) /* fast path */
@@ -1828,7 +1828,7 @@
extent = gegl_buffer_get_extent (buffer);
return g_object_new (GEGL_TYPE_BUFFER,
- "provider", buffer,
+ "source", buffer,
"x", extent->x,
"y", extent->y,
"width", extent->width,
@@ -309,27 +309,27 @@
* we need to create our own
- * provider (this adds a redirectin buffer in between for
+ * source (this adds a redirectin buffer in between for
* all "allocated from format", type buffers.
*/
Modified: trunk/gegl/buffer/gegl-handler-cache.c
==============================================================================